@@ -7,7 +7,7 @@ import tempfile
 import click
 from .tools import __dc
 from .tools import search_env_path
-from . import cli, pass_config
+from .cli import cli, pass_config
 from .lib_clickhelpers import AliasedGroup
 from pathlib import Path
 
@@ -119,7 +119,7 @@ def _turn_into_subvolume(path):
 
 def make_snapshot(ctx, config, name):
     volume_name = __get_postgres_volume_name(config)
-    __dc(["stop", "-t 1"] + ["postgres"])
+    __dc(config, ["stop", "-t 1"] + ["postgres"])
     path = _get_subvolume_dir(config)
     _turn_into_subvolume(DOCKER_VOLUMES / __get_postgres_volume_name(config))
 
@@ -157,7 +157,7 @@ def restore(config, name):
         click.secho(f"Path {name} does not exist.", fg="red")
         sys.exit(-1)
 
-    __dc(["stop", "-t 1"] + ["postgres"])
+    __dc(config, ["stop", "-t 1"] + ["postgres"])
     volume_path = DOCKER_VOLUMES / __get_postgres_volume_name(config)
     if volume_path.exists():
         subprocess.check_call(
@@ -171,8 +171,8 @@ def restore(config, name):
         _get_cmd_butter_volume() + ["snapshot", name, str(volume_path)]
     )
 
-    __dc(["rm", "-f"] + ["postgres"])
-    __dc(["up", "-d"] + ["postgres"])
+    __dc(config, ["rm", "-f"] + ["postgres"])
+    __dc(config, ["up", "-d"] + ["postgres"])
 
 
 def remove(config, snapshot):
